@@ -1431,3 +1431,45 @@ as_date_time_format_iso8601 (GDateTime *datetime)
 	return g_string_free (outstr, FALSE);
 #endif
 }
+
+/**
+ * as_strstripnl:
+ * @string: a string to remove surrounding whitespaces and newlines
+ *
+ * Removes newlines and whitespaces surrounding a string.
+ *
+ * This function doesn't allocate or reallocate any memory;
+ * it modifies @string in place.
+ *
+ * As opposed to g_strstrip() this function also removes newlines
+ * from the start and end of strings.
+ *
+ * Returns: @string
+ */
+gchar*
+as_strstripnl (gchar *string)
+{
+	gsize len;
+	guchar *start;
+	if (string == NULL)
+		return NULL;
+
+	/* remove trailing whitespaces/newlines */
+	len = strlen (string);
+	while (len--) {
+		const guchar c = string[len];
+		if (g_ascii_isspace (c) || (c == '\n'))
+			string[len] = '\0';
+		else
+			break;
+	}
+
+	/* remove leading whitespaces/newlines */
+	for (start = (guchar*) string;
+	     *start && (g_ascii_isspace (*start) || ((*start) == '\n'));
+	     start++)
+	;
+
+	memmove (string, start, strlen ((gchar *) start) + 1);
+	return string;
+}
