@@ -28,6 +28,37 @@
 
 static gchar *datadir = NULL;
 
+/**
+ * test_strstripnl:
+ *
+ * Test our version of strstrip.
+ */
+static void
+test_strstripnl ()
+{
+	gchar *tmp;
+
+	tmp = g_strdup ("     MyString      ");
+	as_strstripnl (tmp);
+	g_assert_cmpstr (tmp, ==, "MyString");
+	g_free (tmp);
+
+	tmp = g_strdup ("\n \n    My\nString \n    \n \n");
+	as_strstripnl (tmp);
+	g_assert_cmpstr (tmp, ==, "My\nString");
+	g_free (tmp);
+
+	tmp = g_strdup ("My\nString");
+	as_strstripnl (tmp);
+	g_assert_cmpstr (tmp, ==, "My\nString");
+	g_free (tmp);
+
+	tmp = g_strdup ("");
+	as_strstripnl (tmp);
+	g_assert_cmpstr (tmp, ==, "");
+	g_free (tmp);
+}
+
 /**
  * test_categories:
  *
@@ -352,6 +383,8 @@ test_spdx (void)
 	g_assert (!as_license_is_free_license ("NOASSERTION"));
 	g_assert (!as_license_is_free_license ("LicenseRef-proprietary=https://example.com/mylicense.txt"));
 	g_assert (!as_license_is_free_license ("MIT AND LicenseRef-proprietary=https://example.com/lic.txt"));
+	g_assert (!as_license_is_free_license ("ADSL"));
+	g_assert (!as_license_is_free_license ("JSON AND GPL-3.0-or-later"));
 }
 
 /**
@@ -609,6 +642,7 @@ main (int argc, char **argv)
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask (NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
+	g_test_add_func ("/AppStream/Strstrip", test_strstripnl);
 	g_test_add_func ("/AppStream/Categories", test_categories);
 	g_test_add_func ("/AppStream/SimpleMarkupConvert", test_simplemarkup);
 	g_test_add_func ("/AppStream/Component", test_component);
